#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['llcsciencesdk']

package_data = \
{'': ['*']}

setup(name='llcsciencesdk',
      version='1.1.3',
      description='A mini SDK for interacting with the LLC Science Admin',
      author='Ariel Delgado',
      author_email='arieldelgado@landlifecompany.com',
      url=None,
      packages=packages,
      package_data=package_data,
     )
